diff --git a/indra/llappearance/lltexturemanagerbridge.h b/indra/llappearance/lltexturemanagerbridge.h
index 101704b16273751c95bca64a766f6ab2b757c596..3c78618cc69db9140cf8c77e2c8753c1fd1e9435 100644
--- a/indra/llappearance/lltexturemanagerbridge.h
+++ b/indra/llappearance/lltexturemanagerbridge.h
@@ -35,7 +35,7 @@
 class LLTextureManagerBridge
 {
 public:
-    virtual ~LLTextureManagerBridge() {}
+	virtual ~LLTextureManagerBridge() = default;
 
 	virtual LLPointer<LLGLTexture> getLocalTexture(BOOL usemipmaps = TRUE, BOOL generate_gl_tex = TRUE) = 0;
 	virtual LLPointer<LLGLTexture> getLocalTexture(const U32 width, const U32 height, const U8 components, BOOL usemipmaps, BOOL generate_gl_tex = TRUE) = 0;
diff --git a/indra/llcommon/llthread.cpp b/indra/llcommon/llthread.cpp
index 6b33d34aa463fd4399f0524f40bb80f96769655a..baf3f6de35cd032ea37e23b96fc316c8307811a0 100644
--- a/indra/llcommon/llthread.cpp
+++ b/indra/llcommon/llthread.cpp
@@ -381,11 +381,3 @@ LLThreadSafeRefCount::~LLThreadSafeRefCount()
 		LL_ERRS() << "deleting referenced object mRef = " << mRef << LL_ENDL;
     }
 }
-
-//============================================================================
-
-LLResponder::~LLResponder()
-{
-}
-
-//============================================================================
diff --git a/indra/llcommon/llthread.h b/indra/llcommon/llthread.h
index b7da25a16aec564f14aabbf43c2cc86422625342..dd1dc2253bff6c6d26cf416fc940ebb09258973b 100644
--- a/indra/llcommon/llthread.h
+++ b/indra/llcommon/llthread.h
@@ -152,7 +152,7 @@ void LLThread::unlockData()
 class LL_COMMON_API LLResponder : public LLThreadSafeRefCount
 {
 protected:
-    virtual ~LLResponder();
+    virtual ~LLResponder() = default;
 public:
     virtual void completed(bool success) = 0;
 };
diff --git a/indra/llrender/llgltexture.h b/indra/llrender/llgltexture.h
index 694ba7b40d2b58e66175159538915ebb868a577a..202e888bc9424f32761cc70fb7f2f1aa98dbb00e 100644
--- a/indra/llrender/llgltexture.h
+++ b/indra/llrender/llgltexture.h
@@ -116,8 +116,8 @@ public:
 	//---------------------------------------------------------------------------------------------
 	//functions to access LLImageGL
 	//---------------------------------------------------------------------------------------------
-	/*virtual*/S32	       getWidth(S32 discard_level = -1) const override;
-	/*virtual*/S32	       getHeight(S32 discard_level = -1) const override;
+	/*virtual*/S32	       getWidth(S32 discard_level = -1) const final override;
+	/*virtual*/S32	       getHeight(S32 discard_level = -1) const final override;
 
 	BOOL       hasGLTexture() const ;
 	LLGLuint   getTexName() const ;		
@@ -155,7 +155,7 @@ public:
 	//---------------------------------------------------------------------------------------------
 
 	//-----------------
-	/*virtual*/ void setActive() override;
+	/*virtual*/ void setActive() final override;
 	void forceActive() ;
 	void setNoDelete() ;
 	void dontDiscard() { mDontDiscard = 1; mTextureState = NO_DELETE; }
@@ -176,7 +176,7 @@ protected:
 	void setTexelsPerImage();
 
 	//note: do not make this function public.
-	/*virtual*/ LLImageGL* getGLTexture() const override;
+	/*virtual*/ LLImageGL* getGLTexture() const final override;
 
 protected:
 	S32 mBoostLevel;				// enum describing priority level
diff --git a/indra/llrender/lltexture.cpp b/indra/llrender/lltexture.cpp
index 90fbcec2bedaad01b3ee84d258c13707fcb4021d..53282bf749e778459f9cb21467897ceb6946ddb9 100644
--- a/indra/llrender/lltexture.cpp
+++ b/indra/llrender/lltexture.cpp
@@ -24,8 +24,3 @@
  */
 #include "linden_common.h"
 #include "lltexture.h"
-
-//virtual 
-LLTexture::~LLTexture()
-{
-}
diff --git a/indra/llrender/lltexture.h b/indra/llrender/lltexture.h
index 9fca8b8cd3a1544e2b05c9fd8c8a2282e082c1d6..f449e22477b5eda8f20b198c5fff9d33a5463cec 100644
--- a/indra/llrender/lltexture.h
+++ b/indra/llrender/lltexture.h
@@ -48,7 +48,7 @@ class LLTexture : public virtual LLRefCount, public LLTrace::MemTrackable<LLText
 	friend class LLFontGL ;
 
 protected:
-	virtual ~LLTexture();
+	virtual ~LLTexture() = default;
 
 public:
 	LLTexture()
diff --git a/indra/llvfs/lllfsthread.h b/indra/llvfs/lllfsthread.h
index 98efc86c077c0b7b92fd3771c1f6d3c4a23bcd5d..76e965c4fe5013f04765e24faa17bbee21329128 100644
--- a/indra/llvfs/lllfsthread.h
+++ b/indra/llvfs/lllfsthread.h
@@ -89,9 +89,9 @@ public:
 			return mFileName;
 		}
 		
-		/*virtual*/ bool processRequest() override;
-		/*virtual*/ void finishRequest(bool completed) override;
-		/*virtual*/ void deleteRequest() override;
+		/*virtual*/ bool processRequest() final override;
+		/*virtual*/ void finishRequest(bool completed) final override;
+		/*virtual*/ void deleteRequest() final override;
 		
 	private:
 		LLLFSThread* mThread;
diff --git a/indra/newview/llagentcamera.h b/indra/newview/llagentcamera.h
index a5603a9e686a6b6354bfa9812c8c793bdc75bd76..1e08e4a493bdc716ef51503c4cfe577ed6e8227d 100644
--- a/indra/newview/llagentcamera.h
+++ b/indra/newview/llagentcamera.h
@@ -79,7 +79,7 @@ public:
 	//--------------------------------------------------------------------
 public:
 	LLAgentCamera();
-	virtual 		~LLAgentCamera();
+	~LLAgentCamera();
 	void			init();
 	void			cleanup();
 	void		    setAvatarObject(LLVOAvatarSelf* avatar);
diff --git a/indra/newview/llfloaterbvhpreview.h b/indra/newview/llfloaterbvhpreview.h
index d882941bf9f4f420f3e1f69d3c70cb03aaf49f1d..6142e93bb67d1018b8f509d6e999922be8536fed 100644
--- a/indra/newview/llfloaterbvhpreview.h
+++ b/indra/newview/llfloaterbvhpreview.h
@@ -37,7 +37,7 @@
 class LLVOAvatar;
 class LLViewerJointMesh;
 
-class LLPreviewAnimation : public LLViewerDynamicTexture
+class LLPreviewAnimation final : public LLViewerDynamicTexture
 {
 protected:
 	virtual ~LLPreviewAnimation();
diff --git a/indra/newview/llfloaterimagepreview.h b/indra/newview/llfloaterimagepreview.h
index 7b006fbab52d4c7b5ee51d5116e7f0ff4a068734..d1f5d7dfd29cfbc2465d2de2bdc1ccc511154b25 100644
--- a/indra/newview/llfloaterimagepreview.h
+++ b/indra/newview/llfloaterimagepreview.h
@@ -39,7 +39,7 @@ class LLTextBox;
 class LLVertexBuffer;
 class LLVolume;
 
-class LLImagePreviewSculpted : public LLViewerDynamicTexture
+class LLImagePreviewSculpted final : public LLViewerDynamicTexture
 {
 protected:
 	virtual ~LLImagePreviewSculpted();
@@ -72,7 +72,7 @@ protected:
 };
 
 
-class LLImagePreviewAvatar : public LLViewerDynamicTexture
+class LLImagePreviewAvatar final : public LLViewerDynamicTexture
 {
 protected:
 	virtual ~LLImagePreviewAvatar();
diff --git a/indra/newview/llfloatermodelpreview.h b/indra/newview/llfloatermodelpreview.h
index 4c276e666f9e62e999d2f1a4c4ef6524df0ec756..3f5c572487ac359cebb12885e3b9a947b777b4e0 100644
--- a/indra/newview/llfloatermodelpreview.h
+++ b/indra/newview/llfloatermodelpreview.h
@@ -230,7 +230,7 @@ private:
 };
 
 
-class LLModelPreview : public LLViewerDynamicTexture, public LLMutex
+class LLModelPreview final : public LLViewerDynamicTexture, public LLMutex
 {	
 	typedef boost::signals2::signal<void (F32 x, F32 y, F32 z, F32 streaming_cost, F32 physics_cost)> details_signal_t;
 	typedef boost::signals2::signal<void (void)> model_loaded_signal_t;
diff --git a/indra/newview/llhudeffectbeam.h b/indra/newview/llhudeffectbeam.h
index b6ccbdcd5a5b9baa540a0b63a6860372bfa68121..d62c22035da78bffb6f9e70762731e5d5ec0b1a0 100644
--- a/indra/newview/llhudeffectbeam.h
+++ b/indra/newview/llhudeffectbeam.h
@@ -37,7 +37,7 @@ class LLViewerObject;
 
 const S32 NUM_POINTS = 5;
 
-class LLHUDEffectBeam : public LLHUDEffect
+class LLHUDEffectBeam final : public LLHUDEffect
 {
 public:
 	/*virtual*/ void setSourceObject(LLViewerObject *objp) final override;
diff --git a/indra/newview/llhudeffectblob.h b/indra/newview/llhudeffectblob.h
index 9217043cd0331f205fd877db6a4a87806dd5f4d5..e0f252293c940a652aec14b828241221e8d83347 100644
--- a/indra/newview/llhudeffectblob.h
+++ b/indra/newview/llhudeffectblob.h
@@ -30,7 +30,7 @@
 #include "llhudeffect.h"
 #include "lluiimage.h"
 
-class LLHUDEffectBlob : public LLHUDEffect
+class LLHUDEffectBlob final : public LLHUDEffect
 {
 public:
 	friend class LLHUDObject;
diff --git a/indra/newview/llhudeffectlookat.h b/indra/newview/llhudeffectlookat.h
index 651547544cb0ca66affbf1deec3e8e93ba97329e..8118e6d58dc8864c528f053bc513d0db1b30f171 100644
--- a/indra/newview/llhudeffectlookat.h
+++ b/indra/newview/llhudeffectlookat.h
@@ -50,7 +50,7 @@ typedef enum e_lookat_type
 	LOOKAT_NUM_TARGETS
 } ELookAtType;
 
-class LLHUDEffectLookAt : public LLHUDEffect
+class LLHUDEffectLookAt final : public LLHUDEffect
 {
 public:
 	friend class LLHUDObject;
diff --git a/indra/newview/llhudeffectpointat.h b/indra/newview/llhudeffectpointat.h
index 787000d64e594b2c73f83ca60b8189bab9325298..1f1178944a4b26612e69ed62054f85a4b77768d2 100644
--- a/indra/newview/llhudeffectpointat.h
+++ b/indra/newview/llhudeffectpointat.h
@@ -42,7 +42,7 @@ typedef enum e_pointat_type
 	POINTAT_NUM_TARGETS
 } EPointAtType;
 
-class LLHUDEffectPointAt : public LLHUDEffect
+class LLHUDEffectPointAt final : public LLHUDEffect
 {
 public:
 	friend class LLHUDObject;
diff --git a/indra/newview/llhudeffecttrail.h b/indra/newview/llhudeffecttrail.h
index 9ecebc2498e237f678be50637038c57ae85bd75e..ee742d5c9a4e8919edeeb1026f528a49b72add0b 100644
--- a/indra/newview/llhudeffecttrail.h
+++ b/indra/newview/llhudeffecttrail.h
@@ -39,7 +39,7 @@ class LLViewerObject;
 constexpr U32 NUM_TRAIL_POINTS = 40;
 
 
-class LLHUDEffectSpiral : public LLHUDEffect
+class LLHUDEffectSpiral final : public LLHUDEffect
 {
 public:
 	/*virtual*/ void markDead() final override;
diff --git a/indra/newview/llhudicon.h b/indra/newview/llhudicon.h
index 25da0b1fc91aed621ac5e597aab865ba13ae56ec..939a0697f3531f55bf1d1ef3b80eeef688001e1f 100644
--- a/indra/newview/llhudicon.h
+++ b/indra/newview/llhudicon.h
@@ -41,7 +41,7 @@
 // Renders a 2D icon billboard floating at the location specified.
 class LLViewerTexture;
 
-class LLHUDIcon : public LLHUDObject
+class LLHUDIcon final : public LLHUDObject
 {
 friend class LLHUDObject;
 
diff --git a/indra/newview/llhudnametag.h b/indra/newview/llhudnametag.h
index 7c3a5ded703e68dc59b254b9203d0ecf5826fdd4..d7f425e0ada2383f42a6a22a1de28c0fe5d7b6a5 100644
--- a/indra/newview/llhudnametag.h
+++ b/indra/newview/llhudnametag.h
@@ -48,7 +48,7 @@ struct llhudnametag_further_away
 	bool operator()(const LLPointer<LLHUDNameTag>& lhs, const LLPointer<LLHUDNameTag>& rhs) const;
 };
 
-class LLHUDNameTag : public LLHUDObject
+class LLHUDNameTag final : public LLHUDObject
 {
 protected:
 	class LLHUDTextSegment
diff --git a/indra/newview/llhudtext.h b/indra/newview/llhudtext.h
index d6c2873c94788059bfadce3be5d82c9664e695df..023c1ef4b63f8ada304c1a385dd3e6245fcf2dfa 100644
--- a/indra/newview/llhudtext.h
+++ b/indra/newview/llhudtext.h
@@ -46,7 +46,7 @@ struct lltextobject_further_away
 	bool operator()(const LLPointer<LLHUDText>& lhs, const LLPointer<LLHUDText>& rhs) const;
 };
 
-class LLHUDText : public LLHUDObject
+class LLHUDText final : public LLHUDObject
 {
 protected:
 	class LLHUDTextSegment
diff --git a/indra/newview/lltexturecache.cpp b/indra/newview/lltexturecache.cpp
index 4112ef1592426276fa455b196e77a09bae6b4b1a..55f9efe3f1f029562288d5f3909fbc07b0e50374 100644
--- a/indra/newview/lltexturecache.cpp
+++ b/indra/newview/lltexturecache.cpp
@@ -59,7 +59,7 @@ class LLTextureCacheWorker : public LLWorkerClass
 	friend class LLTextureCache;
 
 private:
-	class ReadResponder : public LLLFSThread::Responder
+	class ReadResponder final : public LLLFSThread::Responder
 	{
 	public:
 		ReadResponder(LLTextureCache* cache, handle_t handle) : mCache(cache), mHandle(handle) {}
@@ -75,7 +75,7 @@ private:
 		LLTextureCacheWorker::handle_t mHandle;
 	};
 
-	class WriteResponder : public LLLFSThread::Responder
+	class WriteResponder final : public LLLFSThread::Responder
 	{
 	public:
 		WriteResponder(LLTextureCache* cache, handle_t handle) : mCache(cache), mHandle(handle) {}
@@ -136,9 +136,9 @@ public:
 	}
 
 private:
-    void startWork(S32 param) override; // called from addWork() (MAIN THREAD)
-    void finishWork(S32 param, bool completed) override; // called from finishRequest() (WORK THREAD)
-    void endWork(S32 param, bool aborted) override; // called from doWork() (MAIN THREAD)
+    void startWork(S32 param) final override; // called from addWork() (MAIN THREAD)
+    void finishWork(S32 param, bool completed) final override; // called from finishRequest() (WORK THREAD)
+    void endWork(S32 param, bool aborted) final override; // called from doWork() (MAIN THREAD)
 
 protected:
 	LLTextureCache* mCache;
@@ -158,7 +158,7 @@ protected:
 	LLAtomicS32 mBytesRead;
 };
 
-class LLTextureCacheLocalFileWorker : public LLTextureCacheWorker
+class LLTextureCacheLocalFileWorker final : public LLTextureCacheWorker
 {
 public:
 	LLTextureCacheLocalFileWorker(LLTextureCache* cache, U32 priority, const std::string& filename, const LLUUID& id,
@@ -280,7 +280,7 @@ bool LLTextureCacheLocalFileWorker::doWrite()
 	return false;
 }
 
-class LLTextureCacheRemoteWorker : public LLTextureCacheWorker
+class LLTextureCacheRemoteWorker final : public LLTextureCacheWorker
 {
 public:
 	LLTextureCacheRemoteWorker(LLTextureCache* cache, U32 priority, const LLUUID& id,
diff --git a/indra/newview/lltexturecache.h b/indra/newview/lltexturecache.h
index 7ef9612f81fab2454e4acb8999e404bf61ed27f6..9b6ec7b3133607ae9beba3bd6328cd80cc322091 100644
--- a/indra/newview/lltexturecache.h
+++ b/indra/newview/lltexturecache.h
@@ -36,7 +36,7 @@ class LLImageFormatted;
 class LLTextureCacheWorker;
 class LLImageRaw;
 
-class LLTextureCache : public LLWorkerThread
+class LLTextureCache final : public LLWorkerThread
 {
 	friend class LLTextureCacheWorker;
 	friend class LLTextureCacheRemoteWorker;
@@ -83,7 +83,7 @@ public:
 	{
 	public:
 		ReadResponder();
-		void setData(U8* data, S32 datasize, S32 imagesize, S32 imageformat, BOOL imagelocal) override;
+		void setData(U8* data, S32 datasize, S32 imagesize, S32 imageformat, BOOL imagelocal) final override;
 		void setImage(LLImageFormatted* image) { mFormattedImage = image; }
 	protected:
 		LLPointer<LLImageFormatted> mFormattedImage;
@@ -93,7 +93,7 @@ public:
 
 	class WriteResponder : public Responder
 	{
-		void setData(U8* data, S32 datasize, S32 imagesize, S32 imageformat, BOOL imagelocal) override
+		void setData(U8* data, S32 datasize, S32 imagesize, S32 imageformat, BOOL imagelocal) final override
 		{
 			// not used
 		}
diff --git a/indra/newview/lltexturefetch.cpp b/indra/newview/lltexturefetch.cpp
index 15348ae7dde830623dc864ff31e562f241ce30f9..2f1681b532ad2f1f2d492a006761de947ecf4ca1 100644
--- a/indra/newview/lltexturefetch.cpp
+++ b/indra/newview/lltexturefetch.cpp
@@ -295,7 +295,7 @@ class LLTextureFetchWorker : public LLWorkerClass, public LLCore::HttpHandler
 	friend class LLTextureFetchDebugger;
 	
 private:
-	class CacheReadResponder : public LLTextureCache::ReadResponder
+	class CacheReadResponder final : public LLTextureCache::ReadResponder
 	{
 	public:
 
@@ -320,7 +320,7 @@ private:
 		LLUUID mID;
 	};
 
-	class CacheWriteResponder : public LLTextureCache::WriteResponder
+	class CacheWriteResponder final : public LLTextureCache::WriteResponder
 	{
 	public:
 
@@ -344,7 +344,7 @@ private:
 		LLUUID mID;
 	};
 	
-	class DecodeResponder : public LLImageDecodeThread::Responder
+	class DecodeResponder final : public LLImageDecodeThread::Responder
 	{
 	public:
 
@@ -747,8 +747,7 @@ class LLTextureFetch::TFRequest // : public LLQueuedThread::QueuedRequest
 public:
 	// Default ctors and assignment operator are correct.
 
-	virtual ~TFRequest()
-		{}
+	virtual ~TFRequest() = default;
 
 	// Patterned after QueuedRequest's method but expected behavior
 	// is different.  Always expected to complete on the first call
@@ -771,7 +770,7 @@ namespace
  *
  * Corresponds to LLTextureFetch::commandSetRegion()
  */
-class TFReqSetRegion : public LLTextureFetch::TFRequest
+class TFReqSetRegion final : public LLTextureFetch::TFRequest
 {
 public:
 	TFReqSetRegion(U64 region_handle)
@@ -804,7 +803,7 @@ public:
  *
  * Corresponds to LLTextureFetch::commandSendMetrics()
  */
-class TFReqSendMetrics : public LLTextureFetch::TFRequest
+class TFReqSendMetrics final : public LLTextureFetch::TFRequest
 {
 public:
     /**
@@ -3977,7 +3976,7 @@ namespace
 // a Responder that tried harder to detect delivery breaks
 // but it really isn't that important.  If someone wants to
 // revisit that effort, here is a place to start.
-class AssetReportHandler : public LLCore::HttpHandler
+class AssetReportHandler final : public LLCore::HttpHandler
 {
 public:
 
@@ -4145,7 +4144,7 @@ truncate_viewer_metrics(int max_regions, LLSD & metrics)
 //Start LLTextureFetchDebugger
 ///////////////////////////////////////////////////////////////////////////////////////////
 //---------------------
-class LLDebuggerCacheReadResponder : public LLTextureCache::ReadResponder
+class LLDebuggerCacheReadResponder final : public LLTextureCache::ReadResponder
 {
 public:
 	LLDebuggerCacheReadResponder(LLTextureFetchDebugger* debugger, S32 id, LLImageFormatted* image)
@@ -4163,7 +4162,7 @@ private:
 	S32 mID;
 };
 
-class LLDebuggerCacheWriteResponder : public LLTextureCache::WriteResponder
+class LLDebuggerCacheWriteResponder final : public LLTextureCache::WriteResponder
 {
 public:
 	LLDebuggerCacheWriteResponder(LLTextureFetchDebugger* debugger, S32 id)
@@ -4180,7 +4179,7 @@ private:
 	S32 mID;
 };
 
-class LLDebuggerDecodeResponder : public LLImageDecodeThread::Responder
+class LLDebuggerDecodeResponder final : public LLImageDecodeThread::Responder
 {
 public:
 	LLDebuggerDecodeResponder(LLTextureFetchDebugger* debugger, S32 id)
diff --git a/indra/newview/lltoolmorph.h b/indra/newview/lltoolmorph.h
index 62a5d7090f00ae347071250265563aaa539fc9c1..f8e63bdbc9ae5d7d20c6b9d83749285094f664c0 100644
--- a/indra/newview/lltoolmorph.h
+++ b/indra/newview/lltoolmorph.h
@@ -46,7 +46,7 @@ class LLJoint;
 //-----------------------------------------------------------------------------
 // LLVisualParamHint
 //-----------------------------------------------------------------------------
-class LLVisualParamHint : public LLViewerDynamicTexture
+class LLVisualParamHint final : public LLViewerDynamicTexture
 {
 protected:
 	virtual ~LLVisualParamHint();
@@ -101,7 +101,7 @@ protected:
 };
 
 // this class resets avatar data at the end of an update cycle
-class LLVisualParamReset : public LLViewerDynamicTexture
+class LLVisualParamReset final : public LLViewerDynamicTexture
 {
 protected:
 	/*virtual */ ~LLVisualParamReset(){}
diff --git a/indra/newview/llviewertexture.cpp b/indra/newview/llviewertexture.cpp
index c8b5b7fa63ce7c0881cc5a681c14f7c89bd7f507..11b8f2c52be08e42503e9976ff9f3831a896c900 100644
--- a/indra/newview/llviewertexture.cpp
+++ b/indra/newview/llviewertexture.cpp
@@ -343,7 +343,7 @@ LLViewerFetchedTexture* LLViewerTextureManager::getFetchedTextureFromHost(const
 }
 
 // Create a bridge to the viewer texture manager.
-class LLViewerTextureManagerBridge : public LLTextureManagerBridge
+class LLViewerTextureManagerBridge final : public LLTextureManagerBridge
 {
 	/*virtual*/ LLPointer<LLGLTexture> getLocalTexture(BOOL usemipmaps = TRUE, BOOL generate_gl_tex = TRUE) override
     {
diff --git a/indra/newview/llviewertextureanim.h b/indra/newview/llviewertextureanim.h
index 73d74097c67a6ae79f69f3a0e1bf2035b9962277..3e86fa2074a15361e7cce9ae26eb110d14fa7a20 100644
--- a/indra/newview/llviewertextureanim.h
+++ b/indra/newview/llviewertextureanim.h
@@ -32,7 +32,7 @@
 
 class LLVOVolume;
 
-class LLViewerTextureAnim : public LLTextureAnim
+class LLViewerTextureAnim final : public LLTextureAnim
 {
 private:
 	static std::vector<LLViewerTextureAnim*> sInstanceList;
diff --git a/indra/newview/llvoicevisualizer.h b/indra/newview/llvoicevisualizer.h
index 7432bedacb5dc7084780f78b955d48e4fc014a01..2420f09b157aa54b150f5cd093346d9a4effa77c 100644
--- a/indra/newview/llvoicevisualizer.h
+++ b/indra/newview/llvoicevisualizer.h
@@ -65,7 +65,7 @@ const static int NUM_VOICE_SYMBOL_WAVES = 7;
 //----------------------------------------------------
 // LLVoiceVisualizer class 
 //----------------------------------------------------
-class LLVoiceVisualizer : public LLHUDEffect
+class LLVoiceVisualizer final : public LLHUDEffect
 {
 	//---------------------------------------------------
 	// public methods
diff --git a/indra/newview/llviewertexture.h b/indra/newview/llviewertexture.h
index 860490e0b07a8e4dd94c4004a7ed4789d5a37204..6d41db7faa30b7cebc808f4dcced4a5844c4ca6e 100644
--- a/indra/newview/llviewertexture.h
+++ b/indra/newview/llviewertexture.h
@@ -121,12 +121,12 @@ public:
 	virtual BOOL isMissingAsset() const ;
 	void dump() override;	// debug info to LL_INFOS()
 	
-	/*virtual*/ bool bindDefaultImage(const S32 stage = 0) override;
-	/*virtual*/ bool bindDebugImage(const S32 stage = 0) override;
+	/*virtual*/ bool bindDefaultImage(const S32 stage = 0) final override;
+	/*virtual*/ bool bindDebugImage(const S32 stage = 0) final override;
 	/*virtual*/ void forceImmediateUpdate() override;
 	/*virtual*/ bool isActiveFetching() override;
 	
-	/*virtual*/ const LLUUID& getID() const override { return mID; }
+	/*virtual*/ const LLUUID& getID() const final override { return mID; }
 	void setBoostLevel(S32 level);
 	S32  getBoostLevel() { return mBoostLevel; }
 	void setTextureListType(S32 tex_type) { mTextureListType = tex_type; }
@@ -165,7 +165,7 @@ public:
 	BOOL hasParcelMedia() const { return mParcelMedia != nullptr;}
 	LLViewerMediaTexture* getParcelMedia() const { return mParcelMedia;}
 
-	/*virtual*/ void updateBindStatsForTester() override;
+	/*virtual*/ void updateBindStatsForTester() final override;
 protected:
 	void cleanup() ;
 	void init(bool firstinit) ;
@@ -304,8 +304,8 @@ public:
 public:
 	/*virtual*/ S8 getType() const override;
 	FTType getFTType() const;
-	/*virtual*/ void forceImmediateUpdate() override;
-	/*virtual*/ void dump() override;
+	/*virtual*/ void forceImmediateUpdate() final override;
+	/*virtual*/ void dump() final override;
 
 	// Set callbacks to get called when the image gets updated with higher 
 	// resolution versions.
@@ -361,10 +361,10 @@ public:
 	// Override the computation of discard levels if we know the exact output
 	// size of the image.  Used for UI textures to not decode, even if we have
 	// more data.
-	/*virtual*/ void setKnownDrawSize(S32 width, S32 height) override;
+	/*virtual*/ void setKnownDrawSize(S32 width, S32 height) final override;
 
 	void setIsMissingAsset(BOOL is_missing = true);
-	/*virtual*/ BOOL isMissingAsset() const override { return mIsMissingAsset; }
+	/*virtual*/ BOOL isMissingAsset() const final override { return mIsMissingAsset; }
 
 	// returns dimensions of original image for local files (before power of two scaling)
 	// and returns 0 for all asset system images
@@ -407,7 +407,7 @@ public:
 	BOOL        isRawImageValid()const { return mIsRawImageValid ; }	
 	void        forceToSaveRawImage(S32 desired_discard = 0, F32 kept_time = 0.f) ;
 	void        forceToRefetchTexture(S32 desired_discard = 0, F32 kept_time = 60.f);
-	/*virtual*/ void setCachedRawImage(S32 discard_level, LLImageRaw* imageraw) override;
+	/*virtual*/ void setCachedRawImage(S32 discard_level, LLImageRaw* imageraw) final override;
 	void        destroySavedRawImage() ;
 	LLImageRaw* getSavedRawImage() ;
 	BOOL        hasSavedRawImage() const ;
@@ -422,14 +422,14 @@ public:
 	void        setInFastCacheList(bool in_list) { mInFastCacheList = in_list; }
 	bool        isInFastCacheList() { return mInFastCacheList; }
 
 	/*virtual*/bool  isActiveFetching() override; //is actively in fetching by the fetching pipeline.
 	
 	LLUUID		getUploader();
 	LLDate		getUploadTime();
 	std::string getComment();
 
 protected:
-	/*virtual*/ void switchToCachedImage() override;
+	/*virtual*/ void switchToCachedImage() final override;
 	S32 getCurrentDiscardLevelForFetching() ;
 
 private:
@@ -537,7 +537,7 @@ public:
 //the image data is fetched from remote or from local cache
 //the resolution of the texture is adjustable: depends on the view-dependent parameters.
 //
-class LLViewerLODTexture : public LLViewerFetchedTexture
+class LLViewerLODTexture final : public LLViewerFetchedTexture
 {
 protected:
 	/*virtual*/ ~LLViewerLODTexture(){}
@@ -564,7 +564,7 @@ private:
 //the image data is fetched from the media pipeline periodically
 //the resolution of the texture is also adjusted by the media pipeline
 //
-class LLViewerMediaTexture : public LLViewerTexture
+class LLViewerMediaTexture final : public LLViewerTexture
 {
 protected:
 	/*virtual*/ ~LLViewerMediaTexture() ;
@@ -629,7 +629,7 @@ class LLViewerTextureManager
 {
 private:
 	//make the constructor private to preclude creating instances from this class.
-	LLViewerTextureManager(){}
+	LLViewerTextureManager() = delete;
 
 public:
     //texture pipeline tester
@@ -422,14 +422,14 @@ public:
 	bool        isInFastCacheList() { return mInFastCacheList; }
 
-	/*virtual*/bool  isActiveFetching() override; //is actively in fetching by the fetching pipeline.
+	/*virtual*/bool  isActiveFetching() final override; //is actively in fetching by the fetching pipeline.
 	
 	LLUUID		getUploader();